@@ -1,12 +1,12 @@
 package B::Utils::Install::Files;
 
 $self = {
-          'inc' => '',
-          'libs' => '',
           'typemaps' => [
                           'typemap'
                         ],
-          'deps' => []
+          'deps' => [],
+          'inc' => '',
+          'libs' => ''
         };
 
 
